Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
This package contains an OCaml interface for the frei0r library
Please read the COPYING file before using this software.
$ dune buildThis should build both the native and the byte-code version of the extension library.
Via opam:
$ opam install frei0rVia dune (for developers):
$ dune installThis should install the library file in the appropriate place.